@@ -6,18 +6,10 @@ my $ddl_fn = File::Spec->catfile(qw(t lib sqlite.sql));
 # on error
 # The EUMM build-stage generation will run unconditionally and
 # errors will not be trapped
-require DBIx::Class::Optional::Dependencies;
-if ( DBIx::Class::Optional::Dependencies->req_ok_for ('deploy') ) {
-  print "Regenerating t/lib/sqlite.sql\n";
-  if (my $out = ` "$^X" -Ilib maint/gen_schema `) {
-    open (my $fh, '>:unix', $ddl_fn) or die "Unable to open $ddl_fn: $!";
-    print $fh $out;
-    close $fh;
-
-    # if we don't do it some git tools (e.g. gitk) get confused that the
-    # ddl file is modified, when it clearly isn't
-    system('git status --porcelain >' . File::Spec->devnull);
-  }
+if (my $out = ` "$^X" -Ilib maint/gen_schema `) {
+  open (my $fh, '>:unix', $ddl_fn) or die "Unable to open $ddl_fn: $!";
+  print $fh $out;
+  close $fh;
 }
 
 postamble <<"EOP";
@@ -29,5 +21,7 @@ dbic_clonedir_regen_test_ddl :
 @{[ $crlf_fixup->($ddl_fn) ]}
 EOP
 
+
+
 # keep the Makefile.PL eval happy
 1;
